package doctor.common.core.domain;

import doctor.common.core.constant.Constants;
import doctor.common.core.constant.HealthConstants;

import java.io.Serializable;

/**
 * 响应信息主体
 *
 * @author ruoyi
 */
public class HealthR<T> implements Serializable
{
    private static final long serialVersionUID = 1L;

    /** 成功 */
    public static final String SUCCESS = HealthConstants.SUCCESS;

    /** 失败 */
    public static final String FAIL = HealthConstants.FAIL;

    private String message;

    private String status;

    private T result;

    public static <T> HealthR<T> ok()
    {
        return restResult(null,SUCCESS, null);
    }

    public static <T> HealthR<T> ok(T result)
    {
        return restResult(result,SUCCESS, null);
    }

    public static <T> HealthR<T> ok(T result, String message)
    {
        return restResult(result, SUCCESS, message);
    }

    public static <T> HealthR<T> fail()
    {
        return restResult(null,FAIL, null);
    }

    public static <T> HealthR<T> fail(String message)
    {
        return restResult(null, FAIL, message);
    }

    public static <T> HealthR<T> fail(T result)
    {
        return restResult(result,FAIL, null);
    }

    public static <T> HealthR<T> fail(T result, String message)
    {
        return restResult(result,FAIL, message);
    }

    public static <T> HealthR<T> fail(String status, String message)
    {
        return restResult(null, status, message);
    }

    private static <T> HealthR<T> restResult(T result, String status, String message)
    {
        HealthR<T> apiResult = new HealthR<>();
        apiResult.setStatus(status);
        apiResult.setResult(result);
        apiResult.setMessage(message);
        return apiResult;
    }

    public String getMessage()
    {
        return message;
    }

    public void setMessage(String message)
    {
        this.message = message;
    }

    public String getStatus()
    {
        return status;
    }

    public void setStatus(String status)
    {
        this.status = status;
    }

    public T getResult()
    {
        return result;
    }

    public void setResult(T result)
    {
        this.result = result;
    }

    public static <T> Boolean isError(HealthR<T> ret)
    {
        return !isSuccess(ret);
    }

    public static <T> Boolean isSuccess(HealthR<T> ret)
    {
        return HealthR.SUCCESS .equals(ret.getStatus()) ;
    }
}
